.. _swh-loader-core:

Software Heritage - Loader foundations
======================================

Low-level loading utilities and helpers used by other loaders.


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   README


Reference Documentation
-----------------------

.. toctree::
   :maxdepth: 2

   /apidoc/swh.loader.core
